
use gamenight_api_client_rs::{apis::default_api::{participants_get, user_get}, models::{GamenightId, UserId}};
use inquire::Select;
use uuid::Uuid;

use crate::{domain::{gamenight::Gamenight, user::User}, flows::{exit::Exit, join::Join}};

use super::*;

#[derive(Clone)]
pub struct ViewGamenight {
    gamenight: Gamenight
}

impl ViewGamenight {
    pub fn new(gamenight: Gamenight) -> Self {
        Self {
            gamenight
        }
    }
}


fn vec_user_to_usernames_string(users: Vec<User>) -> String {
    
    let string_list: Vec<String> = users.iter().map(|x| {x.username.clone()}).collect();
    string_list.join(", ")
}

#[async_trait]
impl<'a> Flow<'a> for ViewGamenight {
    async fn run(&self, state: &'a mut GamenightState) -> FlowResult<'a> {
        
        let participants = participants_get(&state.configuration, Some(GamenightId{gamenight_id: self.gamenight.id.to_string()})).await?;
        let mut users = vec![];
        for participant in participants.participants.iter() {
            let user = user_get(&state.configuration, Some(UserId{user_id: participant.clone()})).await?;
            users.push(User {
                id: Uuid::parse_str(&user.id)?,
                username: user.username
            });
        }

        println!("{}\nwho: {}", self.gamenight, vec_user_to_usernames_string(users));
        let options: Vec<Box<dyn Flow<'a> + Send>> = vec![
            Box::new(Join::new(self.gamenight.id)),
            Box::new(Exit::new())
        ];
        let choice = Select::new("What do you want to do:", options)
            .prompt_skippable()?;

        handle_choice_option(&choice, self, state).await
    }
}

impl Display for ViewGamenight {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        write!(f, "{} {}", self.gamenight.name, self.gamenight.start_time.format("%d-%m-%Y %H:%M"))
    }
}

